| Title: | Estimating the Age using Auricular Surface by DNE |
|---|---|
| Description: | The age is estimated by calculating the Dirichlet Normal Energy (DNE) on the whole auricular surface and the apex of the auricular surface. It involves three estimation methods: principal component discriminant analysis (PCQDA), and principal component logistic regression analysis (PCLR) methods, principal component regression analysis with Southeast Asian (A_PCR), and principal component regression analysis with multipopulation (M_PCR). The package is created with the data from the Louis Lopes Collection in Lisbon, the 21st Century Identified Human Remains Collection in Coimbra, and the CAL Milano Cemetery Skeletal Collection in Milan, and the skeletal collection at Khon Kaen University (KKU) Human Skeletal Research Centre (HSRC), housed in the Department of Anatomy in the Faculty of Medicine at KKU in Khon Kaen. |
| Authors: | Jisun Jang [aut, cre] |
| Maintainer: | Jisun Jang <[email protected]> |
| License: | GPL-3 |
| Version: | 4.6 |
| Built: | 2026-05-26 06:19:26 UTC |
| Source: | https://github.com/jisunjang19/cran-jsdne |
A_PCR method is the principal component linear regression analysis with Southeast Asian (A_PCR) method using the Dirichlet Normal Energy (DNE). The function automatically calculates the DNE on the auricular surface It provides the estimated age and standard errors (SE, 9.0yrs).
A_PCR_result(x, y)A_PCR_result(x, y)
x |
the name of inputted ply file of the whole auricular surface |
y |
the name of inputted ply file of the apex of the auricular surface |
estimated result gets printed to the console
A_PCR_Test is the test set of the A_PCR model. It consists of Age, MeanDNE.Apex, Proportion.DNEunder0.0001, Proportion.DNEover0.6, IQRDNE.Whole. The number of rows is 66.
A_PCR_TestA_PCR_Test
An object of class data.frame with 66 rows and 5 columns.
A_PCR_Train is the train set of the A_PCR model. It consists of Age, MeanDNE.Apex, Proportion.DNEunder0.0001, Proportion.DNEover0.6, IQRDNE.Whole. The number of rows is 269.
A_PCR_TrainA_PCR_Train
An object of class data.frame with 269 rows and 5 columns.
Surface mesh of apex of auricular surface.
data(Apex)data(Apex)
An object of class mesh3d of length 4.
PCQDA_output <- PCQDA_result(WholeSurface,Apex) PCR_output <- PCR_result(WholeSurface,Apex) PCLR_output <- PCLR_result(WholeSurface,Apex)PCQDA_output <- PCQDA_result(WholeSurface,Apex) PCR_output <- PCR_result(WholeSurface,Apex) PCLR_output <- PCLR_result(WholeSurface,Apex)
It shows the sex and age distribution of the multi-populational sample.
DistributionDistribution
An object of class data.frame with 1225 rows and 3 columns.
FirstObservation is the raw data of DNE variables obtained from the first observation of the Southeast Asian sample. It consists of MeanDNE.Apex, MedianDNE.Apex, IQRDNE.Apex, TotalDNE.TotalPolygonFaces, MedianDNE.Whole, IQRDNE.Whole, MeanDNE.Convex, MeanDNE.Concave, Proportion.DNEunder0.0001 and Proportion.DNEover0.6.
FirstObservationFirstObservation
An object of class data.frame with 140 rows and 10 columns.
M_PCR method is the principal component linear regression analysis with multi-population (M_PCR) method using the Dirichlet Normal Energy (DNE). The function automatically calculates the DNE on the auricular surface It provides the estimated age and standard errors (SE, 10.2yrs).
M_PCR_result(x, y)M_PCR_result(x, y)
x |
the name of inputted ply file of the whole auricular surface |
y |
the name of inputted ply file of the apex of the auricular surface |
estimated result gets printed to the console
M_PCR_Train is the test set of the M_PCR model. It consists of Age,MeanDNE.Apex,MedianDNE.Apex,MeanDNE.Convex,MeanDNE.Concave,Proportion.DNEunder0.0001,Population. The number of rows is 272.
M_PCR_TestM_PCR_Test
An object of class data.frame with 272 rows and 7 columns.
M_PCR_Train is the train set of the M_PCR model. It consists of Age, MeanDNE.Apex, MedianDNE.Apex, MeanDNE.Convex, MeanDNE.Concave, Proportion.DNEunder0.0001, Population. The number of rows is 953.
M_PCR_TrainM_PCR_Train
An object of class data.frame with 953 rows and 7 columns.
MultiData is the combined data of M_PCR train and M_PCR test sets. It consists of Age, MeanDNE.Apex, MedianDNE.Apex, MeanDNE.Convex, MeanDNE.Concave, Proportion.DNEunder0.0001 and Population.
MultiDataMultiData
An object of class data.frame with 1225 rows and 7 columns.
DNE_PCLR method is the principal component logistic regression analysis (PCLR) method using the Dirichlet Normal Energy (DNE). This method involves 2 age groups to distinguish if the specimen is over 63 or under 67. The function automatically calculates the DNE on the auricular surface. It provides the estimated age group and age range of the estimated age group.
PCLR_result(x, y)PCLR_result(x, y)
x |
the name of inputted ply file of the whole auricular surface |
y |
the name of inputted ply file of the apex of the auricular surface |
estimated result gets printed to the console
PCR_Train is the test set of the PCR model. It consists of Age, Cluster1, MeanDNE.Apex, TotalDNE.TotalPolygonFaces, MedianDNE.Whole, IQRDNE.Whole and MeanDNE.Convex. The number of rows is 191.
PCLR_TestPCLR_Test
An object of class data.frame with 191 rows and 7 columns.
PCLR_Train is the train set of the PCR model. It consists of Age, Cluster1, MeanDNE.Apex, TotalDNE.TotalPolygonFaces, MedianDNE.Whole, IQRDNE.Whole and MeanDNE.Convex. The number of rows is 699.
PCLR_TrainPCLR_Train
An object of class data.frame with 699 rows and 7 columns.
DNE_PCQDA method is the principal component quadratic discriminant analysis (PCQDA) method using the Dirichlet Normal Energy (DNE). This method involves 4 age groups. The function automatically calculates the DNE on the auricular surface. It provides the estimated age group and age range of the estimated age group.
PCQDA_result(x, y)PCQDA_result(x, y)
x |
the name of inputted ply file of the whole auricular surface |
y |
the name of inputted ply file of the apex of the auricular surface |
estimated result gets printed to the console
PCQDA_Test is the test set of the PCQDA model. It consists of Cluster2, Age, MeanDNE.Apex, TotalDNE.TotalPolygonFaces, Proportion.DNEunder0.0001, and Proportion.DNEover0.6. The number of rows is 186.
PCQDA_TestPCQDA_Test
An object of class data.frame with 186 rows and 6 columns.
PCQDA_Train is the train set of the PCQDA model. It consists of Cluster2, Age, MeanDNE.Apex, TotalDNE.TotalPolygonFaces, Proportion.DNEunder0.0001, and Proportion.DNEover0.6. The number of rows is 704.
PCQDA_TrainPCQDA_Train
An object of class data.frame with 704 rows and 6 columns.
DNE_PCR method is the principal component linear regression analysis (PCR) method using the Dirichlet Normal Energy (DNE). The function automatically calculates the DNE on the auricular surface It provides the estimated age and standard errors (SE).
PCR_result(x, y)PCR_result(x, y)
x |
the name of inputted ply file of the whole auricular surface |
y |
the name of inputted ply file of the apex of the auricular surface |
estimated result gets printed to the console
PCR_Train is the test set of the PCR model. It consists of Age, MeanDNE.Apex, IQRDNE.Apex, TotalDNE.TotalPolygonFaces, MeanDNE.Convex and Proportion.DNEunder0.0001. The number of rows is 188.
PCR_TestPCR_Test
An object of class data.frame with 188 rows and 6 columns.
PCR_Train is the train set of the PCR model. It consists of Age, MeanDNE.Apex, IQRDNE.Apex, TotalDNE.TotalPolygonFaces, MeanDNE.Convex and Proportion.DNEunder0.0001. The number of rows is 702.
PCR_TrainPCR_Train
An object of class data.frame with 702 rows and 6 columns.
It is the raw data of the DNE variables obtained from the European sample to develop the PCQDA, PCLR, and PCR models. It consists of Age, Cluster1, Cluster2, Collection, Sex, MeanDNE.Apex, MedianDNE.Apex, IQRDNE.Apex, TotalDNE.TotalPolygonFaces, MedianDNE.Whole, IQRDNE.Whole, MeanDNE.Convex, MeanDNE.Concave, Proportion.DNEunder0.0001 and Proportion.DNEover0.6.
RawDataRawData
An object of class data.frame with 890 rows and 15 columns.
SecondObservation is the raw data of DNE variables obtained from the second observation of the Southeast Asian sample. It consists of MeanDNE.Apex, MedianDNE.Apex, IQRDNE.Apex, TotalDNE.TotalPolygonFaces, MedianDNE.Whole, IQRDNE.Whole, MeanDNE.Convex, MeanDNE.Concave, Proportion.DNEunder0.0001 and Proportion.DNEover0.6.
SecondObservationSecondObservation
An object of class data.frame with 140 rows and 10 columns.
ThaiData is the raw data of the DNE variables obtained from the Southeast Asian sample to develop the A_PCR and M_PCR models. It consists of Age, MeanDNE.Apex, MedianDNE.Apex, IQRDNE.Apex, TotalDNE.TotalPolygonFaces, MedianDNE.Whole, IQRDNE.Whole, MeanDNE.Convex, MeanDNE.Concave, Proportion.DNEunder0.0001, Proportion.DNEover0.6, PCQDA_Estimated (results of PCQDA model) and PCR_pred (results of PCR model) , PCLR_pred (results of PCLR model).
ThaiDataThaiData
An object of class data.frame with 335 rows and 14 columns.
TrendLine is the combined data of European and Southeast Asian samples. It consists of Age, MeanDNE.Apex, MedianDNE.Apex, IQRDNE.Apex, TotalDNE.TotalPolygonFaces, MedianDNE.Whole, IQRDNE.Whole, MeanDNE.Convex, MeanDNE.Concave, Proportion.DNEunder0.0001, Proportion.DNEover0.6 and Population.
TrendLineTrendLine
An object of class data.frame with 1225 rows and 12 columns.
Surface mesh of whole auricular surface.
data(WholeSurface)data(WholeSurface)
An object of class mesh3d of length 4.
PCQDA_output <- PCQDA_result(WholeSurface,Apex) PCR_output <- PCR_result(WholeSurface,Apex) PCLR_output <- PCLR_result(WholeSurface,Apex)PCQDA_output <- PCQDA_result(WholeSurface,Apex) PCR_output <- PCR_result(WholeSurface,Apex) PCLR_output <- PCLR_result(WholeSurface,Apex)